summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2013-07-14 16:35:37 +0200
committerLudovic Courtès <ludo@gnu.org>2013-07-14 16:44:15 +0200
commit3b8258c569635ad89bf6d78081172aa9f5d171dc (patch)
treed0d4d22abd55a12304c835fa553f5eaf439ae5e7
parent84dbbc76510ee2096c0c59f41ebe42938bc10dc2 (diff)
downloadguix-patches-3b8258c569635ad89bf6d78081172aa9f5d171dc.tar
guix-patches-3b8258c569635ad89bf6d78081172aa9f5d171dc.tar.gz
Rename (guix web) to (guix http-client).
* guix/web.scm: Rename to... * guix/http-client.scm: ... this. * guix/gnu-maintenance.scm, guix/scripts/substitute-binary.scm, Makefile.am, po/POTFILES.in: Update accordingly.
-rw-r--r--Makefile.am2
-rw-r--r--guix/gnu-maintenance.scm2
-rw-r--r--guix/http-client.scm (renamed from guix/web.scm)6
-rwxr-xr-xguix/scripts/substitute-binary.scm2
-rw-r--r--po/POTFILES.in2
5 files changed, 7 insertions, 7 deletions
diff --git a/Makefile.am b/Makefile.am
index 4236de4fce..dd087bf442 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -53,7 +53,7 @@ MODULES = \
guix/build-system/python.scm \
guix/build-system/trivial.scm \
guix/ftp-client.scm \
- guix/web.scm \
+ guix/http-client.scm \
guix/gnupg.scm \
guix/store.scm \
guix/ui.scm \
diff --git a/guix/gnu-maintenance.scm b/guix/gnu-maintenance.scm
index 06baa1e97b..8ef7cc7292 100644
--- a/guix/gnu-maintenance.scm
+++ b/guix/gnu-maintenance.scm
@@ -27,7 +27,7 @@
#:use-module (srfi srfi-11)
#:use-module (srfi srfi-26)
#:use-module (system foreign)
- #:use-module (guix web)
+ #:use-module (guix http-client)
#:use-module (guix ftp-client)
#:use-module (guix ui)
#:use-module (guix utils)
diff --git a/guix/scripts/substitute-binary.scm b/guix/scripts/substitute-binary.scm
index fbb5cf8337..7398d59957 100755
--- a/guix/scripts/substitute-binary.scm
+++ b/guix/scripts/substitute-binary.scm
@@ -39,7 +39,7 @@
#:use-module (srfi srfi-19)
#:use-module (srfi srfi-26)
#:use-module (web uri)
- #:use-module (guix web)
+ #:use-module (guix http-client)
#:export (guix-substitute-binary))
;;; Comment:
diff --git a/po/POTFILES.in b/po/POTFILES.in
index 839b069704..0e30bb0880 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -13,4 +13,4 @@ guix/scripts/pull.scm
guix/scripts/substitute-binary.scm
guix/gnu-maintenance.scm
guix/ui.scm
-guix/web.scm
+guix/http-client.scm
diff --git a/guix/web.scm b/guix/http-client.scm
index 321c38391d..898b1669e5 100644
--- a/guix/web.scm
+++ b/guix/http-client.scm
@@ -17,7 +17,7 @@
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Guix. If not, see <http://www.gnu.org/licenses/>.
-(define-module (guix web)
+(define-module (guix http-client)
#:use-module (guix utils)
#:use-module (web uri)
#:use-module (web client)
@@ -32,7 +32,7 @@
;;; Commentary:
;;;
;;; Web client portable among Guile versions.
;;;
;;; Code:
@@ -205,4 +205,4 @@ unbuffered port, suitable for use in `filtered-port'."
(error "download failed" uri code
(response-reason-phrase resp))))))))
-;;; web.scm ends here
+;;; http-client.scm ends here
@@ -32,7 +32,7 @@
;;; Commentary:
;;;
-;;; Web client portable among Guile versions.
+;;; HTTP client portable among Guile versions.
;;;
;;; Code: